"use strict";

var _stepParser = require("./step-parser");

test("map lines", function () {
  var steps = [{
    lines: [1, 3]
  }, {
    lines: [5],
    note: "foo"
  }];
  var expected = [{
    1: null,
    3: null
  }, {
    5: null
  }];
  var tokenSteps = steps.map(_stepParser.mapStep);
  expect(tokenSteps).toEqual(expected);
});
test("map range", function () {
  var steps = [{
    range: [1, 3]
  }, {
    range: [1, 1],
    note: "foo"
  }];
  var expected = [{
    1: null,
    2: null,
    3: null
  }, {
    1: null
  }];
  var tokenSteps = steps.map(_stepParser.mapStep);
  expect(tokenSteps).toEqual(expected);
});
test("map ranges", function () {
  var steps = [{
    ranges: [[1, 2], [5, 5]]
  }];
  var expected = [{
    1: null,
    2: null,
    5: null
  }];
  var tokenSteps = steps.map(_stepParser.mapStep);
  expect(tokenSteps).toEqual(expected);
});
test("map tokens", function () {
  var steps = [{
    tokens: {
      1: [1, 2],
      2: null,
      5: null
    }
  }];
  var expected = [{
    1: [1, 2],
    2: null,
    5: null
  }];
  var tokenSteps = steps.map(_stepParser.mapStep);
  expect(tokenSteps).toEqual(expected);
});
test("map range, ranges and tokens", function () {
  var steps = [{
    tokens: {
      1: null
    },
    range: [3, 4],
    ranges: [[6, 6], [8, 8]]
  }];
  var expected = [{
    1: null,
    3: null,
    4: null,
    6: null,
    8: null
  }];
  var tokenSteps = steps.map(_stepParser.mapStep);
  expect(tokenSteps).toEqual(expected);
});
test("map lines syntax", function () {
  var step = "1, 3";
  var expected = {
    1: null,
    3: null
  };
  var result = (0, _stepParser.mapStep)(step);
  expect(result).toEqual(expected);
});
test("map range syntax", function () {
  var step = "1:3, 5:6";
  var expected = {
    1: null,
    2: null,
    3: null,
    5: null,
    6: null
  };
  var result = (0, _stepParser.mapStep)(step);
  expect(result).toEqual(expected);
});
test("map tokens syntax", function () {
  var step = "1[2,3], 2[3]";
  var expected = {
    1: [2, 3],
    2: [3]
  };
  var result = (0, _stepParser.mapStep)(step);
  expect(result).toEqual(expected);
});
test("map range tokens syntax", function () {
  var step = "1[2:3]";
  var expected = {
    1: [2, 3]
  };
  var result = (0, _stepParser.mapStep)(step);
  expect(result).toEqual(expected);
});
test("map complex syntax", function () {
  var step = "1[2, 3,  6:9],   2[3], 5, 6:7";
  var expected = {
    1: [2, 3, 6, 7, 8, 9],
    2: [3],
    5: null,
    6: null,
    7: null
  };
  var result = (0, _stepParser.mapStep)(step);
  expect(result).toEqual(expected);
});
test("map star syntax", function () {
  var step = "* ";
  var expected = {
    all: true
  };
  var result = (0, _stepParser.mapStep)(step);
  expect(result).toEqual(expected);
});
test("map empty object", function () {
  var step = {};
  var expected = {
    all: true
  };
  var result = (0, _stepParser.mapStep)(step);
  expect(result).toEqual(expected);
});